package routes

/**
 * 配置路由
 */
import (
	"PaymentCenter/app/constants/common"
	"PaymentCenter/app/http/controllers"
	"PaymentCenter/app/http/controllers/front"
	"PaymentCenter/app/http/middlewares"
	"PaymentCenter/app/http/trace"
	"PaymentCenter/app/utils/metric"
	"PaymentCenter/config"
	ginSwagger "github.com/swaggo/gin-swagger"
	"github.com/swaggo/gin-swagger/swaggerFiles"

	"github.com/gin-gonic/gin"
	"github.com/qit-team/snow-core/http/middleware"
	"github.com/qit-team/snow-core/log/logger"
)

// api路由配置
func RegisterRoute(router *gin.Engine) {
	//middleware: 服务错误处理 => 生成请求id => access log
	router.Use(middlewares.ServerRecovery(), middleware.GenRequestId, middleware.GenContextKit, middleware.AccessLog())

	if config.GetConf().PrometheusCollectEnable && config.IsEnvEqual(config.ProdEnv) {
		router.Use(middlewares.CollectMetric())
		metric.Init(metric.EnableRuntime(), metric.EnableProcess())
		metricHandler := metric.Handler()
		router.GET("/metrics", func(ctx *gin.Context) {
			metricHandler.ServeHTTP(ctx.Writer, ctx.Request)
		})
	}

	if len(config.GetConf().SkyWalkingOapServer) > 0 && config.IsEnvEqual(config.ProdEnv) {
		err := trace.InitTracer(config.GetConf().ServiceName, config.GetConf().SkyWalkingOapServer)
		if err != nil {
			logger.Error(nil, "InitTracer", err.Error())
		} else {
			router.Use(middlewares.Trace())
		}
	}

	router.Use(middlewares.Cors())
	router.NoRoute(controllers.Error404)

	//router.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

	v1 := router.Group(common.FRONT_V1)
	{
		//回调处理
		notify := v1.Group("/notify")
		{
			notify.POST("/wx/:payChannelId", front.WxCallback)
			notify.POST("/ali/:payChannelId", front.AliCallback)
		}

		pay := v1.Group("/pay", middlewares.ValidateRequest(), middlewares.ValidatePayRequest())
		{
			pay.POST("/url", front.PayUrl)
			pay.POST("/query", front.QueryOrder) //查询订单
		}
	}

	router.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))

}
